@@ -1,6 +1,6 @@
 package SPVM::Go;
 
-our $VERSION = "0.003";
+our $VERSION = "0.004";
 
 1;
 
@@ -76,12 +76,16 @@ Suspends the current goroutine for IO reading given the file descriptor $fd and
 
 The control is transferred to the scheduler.
 
-The value of $timeout_ref is updated by the rest timeout. If it is less than 0, timeout has occured.
+The value of $timeout_ref is updated to a negative value if timeout occured.
 
 Exceptions:
 
 This method must be called from the main thread. Otherwise an exception is thrown.
 
+The value of $timeout_ref must be greater than 0. Otherwise an exception is thrown.
+
+The value of $timeout_ref must be less than or equal to Fn->INT_MAX. Otherwise an exception is thrown.
+
 =head2 gosched_io_write
 
 C<static method gosched_io_write : void ($fd : int, $timeout_ref : double[] = undef);>
@@ -90,12 +94,16 @@ Suspends the current goroutine for IO writing given the file descriptor $fd and
 
 The control is transferred to the scheduler.
 
-The value of $timeout_ref is updated by the rest timeout. If it is less than 0, timeout has occured.
+The value of $timeout_ref is updated to a negative value if timeout occured.
 
 Exceptions:
 
 This method must be called from the main thread. Otherwise an exception is thrown.
 
+The value of $timeout_ref must be greater than 0. Otherwise an exception is thrown.
+
+The value of $timeout_ref must be less than or equal to Fn->INT_MAX. Otherwise an exception is thrown.
+
 =head2 sleep
 
 C<static method sleep : void ($seconds : double = 0);>
@@ -106,6 +114,8 @@ Exceptions:
 
 This method must be called from the main thread. Otherwise an exception is thrown.
 
+$seconds must be less than or equal to Fn->INT_MAX. Otherwise an exception is thrown.
+
 =head1 Repository
 
 L<SPVM::Go - Github|https://github.com/yuki-kimoto/SPVM-Go>
